import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useContext, useRef, useState } from 'react';
import classnames from 'classnames';
import ConfigProviderContext from '../config-provider/ConfigProviderContext';
import { pick } from '../utils';
import Icon from '../icon';
import Swiper from '../swiper';
import ImagePreviewItem from './ImagePreviewItem';
import Popup from '../popup';

var ImagePreview = function ImagePreview(props) {
  var _useContext = useContext(ConfigProviderContext),
      prefixCls = _useContext.prefixCls,
      createNamespace = _useContext.createNamespace;

  var _createNamespace = createNamespace('image-preview', prefixCls),
      _createNamespace2 = _slicedToArray(_createNamespace, 1),
      bem = _createNamespace2[0];

  var _useState = useState(function () {
    return props.startPosition;
  }),
      _useState2 = _slicedToArray(_useState, 2),
      active = _useState2[0],
      setActive = _useState2[1];

  var swiperRef = useRef(null);

  var onSwipeChange = function onSwipeChange(idx) {
    if (active !== idx) {
      var _props$onChange;

      setActive(idx);
      (_props$onChange = props.onChange) === null || _props$onChange === void 0 ? void 0 : _props$onChange.call(props, idx);
    }
  };

  var renderImages = function renderImages() {
    return /*#__PURE__*/React.createElement(Swiper, {
      ref: swiperRef,
      defaultIndex: active,
      loop: props.loop,
      className: classnames(bem('swipe')),
      autoplayInterval: props.swipeDuration,
      onIndexChange: onSwipeChange,
      indicator: props.showIndicators
    }, props.images.map(function (image, i) {
      return (
        /*#__PURE__*/
        // eslint-disable-next-line react/no-array-index-key
        React.createElement(Swiper.Item, {
          className: classnames(bem('item')),
          key: image
        }, /*#__PURE__*/React.createElement(ImagePreviewItem, {
          maxZoom: props.maxZoom,
          image: image,
          onTap: function onTap() {
            var _props$onClose;

            (_props$onClose = props.onClose) === null || _props$onClose === void 0 ? void 0 : _props$onClose.call(props, {
              url: image,
              index: i
            });
          },
          onZoomChange: function onZoomChange(zoom) {
            if (zoom !== 1) {
              var _swiperRef$current;

              (_swiperRef$current = swiperRef.current) === null || _swiperRef$current === void 0 ? void 0 : _swiperRef$current.lock();
            } else {
              var _swiperRef$current2;

              (_swiperRef$current2 = swiperRef.current) === null || _swiperRef$current2 === void 0 ? void 0 : _swiperRef$current2.unlock();
            }
          }
        }))
      );
    }));
  };

  var renderClose = function renderClose() {
    if (props.closeable) {
      return /*#__PURE__*/React.createElement(Icon, {
        name: props.closeIcon,
        className: classnames(bem('close-icon', props.closeIconPosition)),
        onClick: function onClick() {
          var _props$onClose2;

          return (_props$onClose2 = props.onClose) === null || _props$onClose2 === void 0 ? void 0 : _props$onClose2.call(props);
        }
      });
    }

    return null;
  };

  var renderIndex = function renderIndex() {
    if (props.showIndex) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(bem('index'))
      }, props.indexRender ? props.indexRender({
        index: active,
        len: props.images.length
      }) : "".concat(active + 1, " / ").concat(props.images.length));
    }

    return null;
  };

  return /*#__PURE__*/React.createElement(Popup, _extends({
    className: classnames(props.className, bem()),
    overlayClass: classnames(bem('overlay')),
    beforeClose: props.beforeClose
  }, pick(props, ['visible', 'overlayStyle', 'closeOnPopstate', 'onClose', 'onClosed'])), renderClose(), renderImages(), renderIndex());
};

ImagePreview.defaultProps = {
  loop: true,
  overlay: true,
  showIndex: true,
  images: [],
  swipeDuration: 300,
  startPosition: 0,
  closeIcon: 'clear',
  closeIconPosition: 'top-right',
  showIndicators: false
};
export default ImagePreview;