import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React from 'react';
import { mount } from 'enzyme';
import { act } from 'react-dom/test-utils';
import { sleep } from '../../../tests/utils';
import NoticeBar from '..';
import Icon from '../../icon';
describe('NoticeBar', function () {
  var wrapper;
  afterEach(function () {
    wrapper.unmount();
    jest.restoreAllMocks();
  });
  it('should render left icon correct', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              leftIcon: "speaker-s",
              text: "foo"
            }));
            expect(wrapper.html()).toMatchSnapshot();

          case 2:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  })));
  it('should render right icon correct', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2() {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              rightIcon: "speaker-s",
              text: "foo"
            }));
            expect(wrapper.html()).toMatchSnapshot();

          case 2:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  })));
  it('should render ReactNode icon correct', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee3() {
    return _regeneratorRuntime.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              leftIcon: /*#__PURE__*/React.createElement(Icon, {
                name: "cart-o",
                color: "#1989fa"
              }),
              text: "foo"
            }));
            expect(wrapper.html()).toMatchSnapshot();

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  })));
  it('should render link mode correct', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee4() {
    return _regeneratorRuntime.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              mode: "link",
              text: "foo"
            }));
            expect(wrapper.find('.rc-notice-bar__right-icon').at(1).hasClass('van-icon-arrow')).toBeTruthy();

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  })));
  it('should emit close event when close icon is clicked', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee5() {
    var onClose, item;
    return _regeneratorRuntime.wrap(function _callee5$(_context5) {
      while (1) {
        switch (_context5.prev = _context5.next) {
          case 0:
            onClose = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              mode: "closeable",
              text: "foo",
              onClose: onClose
            }));
            item = wrapper.find('.rc-notice-bar__right-icon');
            _context5.next = 5;
            return item.at(0).simulate('click');

          case 5:
            expect(onClose).toHaveBeenCalledTimes(1);

          case 6:
          case "end":
            return _context5.stop();
        }
      }
    }, _callee5);
  })));
  it('should emit replay event after replay', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee6() {
    var onReplay;
    return _regeneratorRuntime.wrap(function _callee6$(_context6) {
      while (1) {
        switch (_context6.prev = _context6.next) {
          case 0:
            onReplay = jest.fn();
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              text: "foo",
              onReplay: onReplay
            }));
            wrapper.find('.rc-notice-bar__content').simulate('transitionend');
            _context6.next = 5;
            return sleep(80);

          case 5:
            expect(onReplay).toHaveBeenCalledTimes(1);

          case 6:
          case "end":
            return _context6.stop();
        }
      }
    }, _callee6);
  })));
  it('should start scrolling when content width > wrap width ', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee7() {
    var wrap, content;
    return _regeneratorRuntime.wrap(function _callee7$(_context7) {
      while (1) {
        switch (_context7.prev = _context7.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              text: "foo",
              delay: 0
            }));
            wrap = wrapper.find('.rc-notice-bar__wrap');
            content = wrapper.find('.rc-notice-bar__content');

            wrap.getBoundingClientRect = function () {
              return {
                width: 50
              };
            };

            content.getBoundingClientRect = function () {
              return {
                width: 100
              };
            };

            _context7.next = 7;
            return sleep(50);

          case 7:
            expect(wrapper.html()).toMatchSnapshot();

          case 8:
          case "end":
            return _context7.stop();
        }
      }
    }, _callee7);
  })));
  it('should not start scrolling when content width > wrap width and props scrollable is false  ', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee8() {
    var wrap, content;
    return _regeneratorRuntime.wrap(function _callee8$(_context8) {
      while (1) {
        switch (_context8.prev = _context8.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              text: "foo",
              scrollable: false,
              delay: 0
            }));
            wrap = wrapper.find('.rc-notice-bar__wrap');
            content = wrapper.find('.rc-notice-bar__content');

            wrap.getBoundingClientRect = function () {
              return {
                width: 50
              };
            };

            content.getBoundingClientRect = function () {
              return {
                width: 100
              };
            };

            _context8.next = 7;
            return sleep(50);

          case 7:
            expect(wrapper.html()).toMatchSnapshot();

          case 8:
          case "end":
            return _context8.stop();
        }
      }
    }, _callee8);
  })));
  it('should not start scrolling when content width > wrap width ', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee9() {
    var wrap, content;
    return _regeneratorRuntime.wrap(function _callee9$(_context9) {
      while (1) {
        switch (_context9.prev = _context9.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              text: "foo",
              delay: 0
            }));
            wrap = wrapper.find('.rc-notice-bar__wrap');
            content = wrapper.find('.rc-notice-bar__content');

            wrap.getBoundingClientRect = function () {
              return {
                width: 200
              };
            };

            content.getBoundingClientRect = function () {
              return {
                width: 100
              };
            };

            _context9.next = 7;
            return sleep(50);

          case 7:
            expect(wrapper.html()).toMatchSnapshot();

          case 8:
          case "end":
            return _context9.stop();
        }
      }
    }, _callee9);
  })));
  it('should start scrolling when content width > wrap width and props scrollable is true', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee10() {
    var wrap, content;
    return _regeneratorRuntime.wrap(function _callee10$(_context10) {
      while (1) {
        switch (_context10.prev = _context10.next) {
          case 0:
            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              text: "foo",
              scrollable: true,
              delay: 0
            }));
            wrap = wrapper.find('.rc-notice-bar__wrap');
            content = wrapper.find('.rc-notice-bar__content');

            wrap.getBoundingClientRect = function () {
              return {
                width: 200
              };
            };

            content.getBoundingClientRect = function () {
              return {
                width: 100
              };
            };

            _context10.next = 7;
            return sleep(50);

          case 7:
            expect(wrapper.html()).toMatchSnapshot();

          case 8:
          case "end":
            return _context10.stop();
        }
      }
    }, _callee10);
  })));
  it('should expose reset methods', /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee12() {
    var NoticeBarRef, reset;
    return _regeneratorRuntime.wrap(function _callee12$(_context12) {
      while (1) {
        switch (_context12.prev = _context12.next) {
          case 0:
            NoticeBarRef = /*#__PURE__*/React.createRef();

            reset = function reset() {
              NoticeBarRef.current.reset();
            };

            wrapper = mount( /*#__PURE__*/React.createElement(NoticeBar, {
              ref: NoticeBarRef,
              scrollable: true,
              text: "foo"
            }));
            _context12.next = 5;
            return act( /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee11() {
              return _regeneratorRuntime.wrap(function _callee11$(_context11) {
                while (1) {
                  switch (_context11.prev = _context11.next) {
                    case 0:
                      reset();

                    case 1:
                    case "end":
                      return _context11.stop();
                  }
                }
              }, _callee11);
            })));

          case 5:
            expect(wrapper.html()).toMatchSnapshot();

          case 6:
          case "end":
            return _context12.stop();
        }
      }
    }, _callee12);
  })));
});